document.addEventListener('DOMContentLoaded', () => {
  const riskThreshold = document.getElementById('riskThreshold');
  const riskValue = document.getElementById('riskValue');
  const indicatorThreshold = document.getElementById('indicatorThreshold');
  const indicatorValue = document.getElementById('indicatorValue');
  const enableLiveChecks = document.getElementById('enableLiveChecks');
  const saveButton = document.getElementById('saveButton');
  const successMessage = document.getElementById('successMessage');

  // Convert slider value (1-5) to risk threshold (0-100)
  function sliderToRiskLevel(value) {
    return value * 20;
  }

  // Convert risk threshold (0-100) to slider value (1-5)
  function riskLevelToSlider(value) {
    return Math.ceil(value / 20);
  }

  // Load saved settings
  chrome.storage.sync.get(['riskThreshold', 'indicatorThreshold', 'enableLiveChecks'], (data) => {
    const riskLevel = data.riskThreshold || 60;
    riskThreshold.value = riskLevelToSlider(riskLevel);
    riskValue.textContent = getRiskLevelLabel(riskLevel);
    updateRiskValueColor(riskValue, riskLevel);

    const indicatorLevel = data.indicatorThreshold || 40;
    indicatorThreshold.value = riskLevelToSlider(indicatorLevel);
    indicatorValue.textContent = getRiskLevelLabel(indicatorLevel);
    updateRiskValueColor(indicatorValue, indicatorLevel);

    const shouldEnableLiveChecks = data.enableLiveChecks !== false; // Default to true
    enableLiveChecks.checked = shouldEnableLiveChecks;
  });

  // Update value display when risk threshold changes
  riskThreshold.addEventListener('input', (e) => {
    const sliderValue = parseInt(e.target.value);
    const riskLevel = sliderToRiskLevel(sliderValue);
    riskValue.textContent = getRiskLevelLabel(riskLevel);
    updateRiskValueColor(riskValue, riskLevel);
  });

  // Update value display when indicator threshold changes
  indicatorThreshold.addEventListener('input', (e) => {
    const sliderValue = parseInt(e.target.value);
    const riskLevel = sliderToRiskLevel(sliderValue);
    indicatorValue.textContent = getRiskLevelLabel(riskLevel);
    updateRiskValueColor(indicatorValue, riskLevel);
  });

  // Save settings
  saveButton.addEventListener('click', () => {
    const riskLevel = sliderToRiskLevel(parseInt(riskThreshold.value));
    const indicatorLevel = sliderToRiskLevel(parseInt(indicatorThreshold.value));
    const shouldEnableLive = enableLiveChecks.checked;

    // Disable button while saving
    saveButton.disabled = true;

    chrome.storage.sync.set({
      riskThreshold: riskLevel,
      indicatorThreshold: indicatorLevel,
      enableLiveChecks: shouldEnableLive
    }, () => {
      // Show success message
      successMessage.classList.add('visible');

      // Re-enable button
      saveButton.disabled = false;

      // Hide success message after 2 seconds
      setTimeout(() => {
        successMessage.classList.remove('visible');
      }, 2000);

      // Notify background script about settings change
      chrome.runtime.sendMessage({ type: 'settingsUpdated' });
    });
  });

  // Get risk level label based on value
  function getRiskLevelLabel(value) {
    if (value >= 81) return 'No Trust';
    if (value >= 61) return 'Low Trust';
    if (value >= 41) return 'Moderate Trust';
    if (value >= 21) return 'High Trust';
    return 'Very High Trust';
  }

  // Update risk value color based on threshold
  function updateRiskValueColor(element, value) {
    if (value >= 81) {
      element.style.color = '#ef4444'; // red-500
    } else if (value >= 61) {
      element.style.color = '#f97316'; // orange-500
    } else if (value >= 41) {
      element.style.color = '#eab308'; // yellow-500
    } else if (value >= 21) {
      element.style.color = '#84cc16'; // lime-500
    } else {
      element.style.color = '#22c55e'; // green-500
    }
  }
}); 